@@ -2,6 +2,7 @@
 import typing
 import logging
 from simpleschema.helper_classes import ObjectSchema
+from simpleschema.exceptions import ValidationFailure
 
 
 logger = logging.getLogger(__name__)
@@ -18,7 +19,7 @@ def is_valid(item: dict, schema: typing.Union[dict, ObjectSchema]) -> bool:
 	"""
 	try:
 		return validateSchema(item, schema)
-	except ValueError:
+	except ValidationFailure:
 		return False
 
 
@@ -50,12 +51,12 @@ def validateSchema(item: dict, schema: typing.Union[dict, ObjectSchema]) -> bool
 			See simpleschema.ObjectSchema for example usage.
 
 	Raises:
-		ValueError: The key or value that has failed to validate, and the reason.
+		ValidationFailure: The key or value that has failed to validate, and the reason.
 
 	Returns:
 		bool: If the schema validates, returns True.
 			Note that this *only* returns True. If the schema fails to validate, we instead raise
-			a ValueError, which includes information about the validation failure.
+			a ValidationFailure, which includes information about the validation failure.
 	"""
 	logger.debug(f'Validating schema {schema} against item {item}')
 	if isinstance(schema, ObjectSchema):
@@ -71,10 +72,10 @@ def validateSchema(item: dict, schema: typing.Union[dict, ObjectSchema]) -> bool
 					validateItem(item_key, schema_key)
 					validateItem(item_val, schema_val)
 					break
-				except ValueError as e:
+				except ValidationFailure as e:
 					logger.debug(e)
 			else:
-				raise ValueError(f'Schema key `{schema_key}`: schema value `{schema_val}` - No valid key/value pair found in item')
+				raise ValidationFailure(f'Schema key `{schema_key}`: schema value `{schema_val}` - No valid key/value pair found in item')
 	return True
 
 
@@ -87,7 +88,7 @@ def validateItem(item_val: typing.Any, schema_val: typing.Any) -> bool:
 		schema_val (typing.Any): The schema constraint to validate against
 
 	Raises:
-		ValueError: If the value does not validate
+		ValidationFailure: If the value does not validate
 
 	Returns:
 		bool: If the value validates, returns True
@@ -101,7 +102,7 @@ def validateItem(item_val: typing.Any, schema_val: typing.Any) -> bool:
 		literal_args = typing.get_args(schema_val)
 		if literal_args and literal_args[0] == item_val:
 			return True
-		raise ValueError(f'Schema constraint `{schema_val}`, item `{item_val}` - Literal mismatch')
+		raise ValidationFailure(f'Schema constraint `{schema_val}`, item `{item_val}` - Literal mismatch')
 	elif isinstance(schema_val, dict) and isinstance(item_val, dict):
 		return validateSchema(item_val, schema_val)
 	elif (
@@ -110,7 +111,7 @@ def validateItem(item_val: typing.Any, schema_val: typing.Any) -> bool:
 	):
 		if isinstance(item_val, schema_val):
 			return True
-		raise ValueError(f'Schema constraint `{schema_val}`, item `{item_val}` - Type requirement mismatch')
+		raise ValidationFailure(f'Schema constraint `{schema_val}`, item `{item_val}` - Type requirement mismatch')
 	elif isinstance(schema_val, typing.Iterable) and not isinstance(schema_val, (str, bytes)):
 		for schema_val_option in schema_val:
 			if schema_val_option != schema_val:
@@ -119,15 +120,15 @@ def validateItem(item_val: typing.Any, schema_val: typing.Any) -> bool:
 				try:
 					validateItem(item_val, schema_val_option)
 					return True
-				except ValueError as e:
+				except ValidationFailure as e:
 					logger.debug(e)
-		raise ValueError(f'Schema constraint `{schema_val}`, item `{item_val}` - No item values validate for schema options')
+		raise ValidationFailure(f'Schema constraint `{schema_val}`, item `{item_val}` - No item values validate for schema options')
 	elif callable(schema_val):
 		if schema_val(item_val):
 			return True
-		raise ValueError(f'Schema constraint `{schema_val}`, item `{item_val}` - Function does not validate')
+		raise ValidationFailure(f'Schema constraint `{schema_val}`, item `{item_val}` - Function does not validate')
 	else:
-		raise ValueError(f'Schema constraint `{schema_val}`, item `{item_val}` - Item does not validate')
+		raise ValidationFailure(f'Schema constraint `{schema_val}`, item `{item_val}` - Item does not validate')
 
 
 
